//+------------------------------------------------------------------+
//|                                           MA_ProximitySensor.mq4 |
//|                                                     Ptaczek 2007 |
//|                                               ptaczek@centrum.cz |
//+------------------------------------------------------------------+

#property copyright "ptaczek 2007"
#property link      ""

#property indicator_chart_window

#property indicator_buffers 1

// MA
#property indicator_color1 Blue

extern int exMaPeriod = 34;
extern string exMaType = "ema"; // lower case string: "ema", "sma", "smma", "lwma"
extern bool exMaVisible = true;
extern int alertPipsDistance = 2;

// buffers
double ma[];

/*
   +------------------------------------------------------------------+
   | Custom indicator initialization function                         |
   +------------------------------------------------------------------+
*/
int init()
{
   // MA indicators
   SetIndexStyle(0, DRAW_LINE);
   SetIndexBuffer(0, ma);
   
   return(0);
}
  
/*
   +------------------------------------------------------------------+
   | Custor indicator deinitialization function                       |
   +------------------------------------------------------------------+
*/
int deinit()
{
   return(0);
}

/*
   +------------------------------------------------------------------+
   | Custom indicator iteration function                              |
   +------------------------------------------------------------------+
*/
int start()
{
   int limit;
   int counted_bars = IndicatorCounted();
   
   // check for possible errors
   if( counted_bars < 0 )
   {
      return(-1);
   }
   
   // last counted bar will be recounted
   if( counted_bars > 0 )
   {
      counted_bars--;
   }
   
   limit = Bars - counted_bars;

   // decide the MA type
   int maType = getMaType(exMaType);

   // draw the MA
   if( exMaVisible )
   {
      for(int i = 0; i < limit; i++)
      {
         // draw moving averages
         ma[i]  = iMA(NULL, 0,  exMaPeriod, 0, maType, PRICE_CLOSE, i);
      }
   }

   // compute price-to-MA distance
   double distance = MathAbs((Close[0] - iMA(NULL, 0, exMaPeriod, 0, maType, PRICE_CLOSE, 0)) / Point);
   
   // alert check
   if( distance <= alertPipsDistance )
   {
      PlaySound("alert2.wav");
   }
   
   //Comment("Price-to-MA distance: " + distance);

   return(0);
}

int getMaType(string exMaType)
{
   if( exMaType == "ema" )
   {
      return(MODE_EMA);
   }
   else if( exMaType == "sma" )
   {
      return(MODE_SMA);
   }
   else if( exMaType == "smma" )
   {
      return(MODE_SMMA);
   }
   else if( exMaType == "lwma" )
   {
      return(MODE_LWMA);
   }
   else
   {
      return(MODE_EMA);
   }
}